==> haskell-transformers-compat-0.5.1.4-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-transformers-compat.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: transformers-compat
version: 0.5.1.4
id: transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
key: transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
license: BSD3
copyright: Copyright (C) 2012-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/transformers-compat/
synopsis: A small compatibility shim exposing the new types from transformers 0.3 and 0.4 to older Haskell platforms.
description:
    This package includes backported versions of types that were added
    to transformers in transformers 0.3, 0.4, and 0.5 for users who need strict
    transformers 0.2 or 0.3 compatibility to run on old versions of the
    platform, but also need those types.
    .
    Those users should be able to just depend on @transformers >= 0.2@
    and @transformers-compat >= 0.3@.
    .
    Note: missing methods are not supplied, but this at least permits the types to be used.
category: Compatibility
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Monad.Trans.Instances
hidden-modules: Paths_transformers_compat
abi: 676963e4484625503b8123c4c46f67b9
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/transformers-compat-0.5.1.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/transformers-compat-0.5.1.4
data-dir: /usr/share/arm-linux-ghc-8.0.1/transformers-compat-0.5.1.4
hs-libraries: HStransformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
depends:
    base-4.9.0.0 ghc-prim-0.5.0.0 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-transformers-compat/html/transformers-compat.haddock
haddock-html: /usr/share/doc/haskell-transformers-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-transformers-compat-0.5.1.4-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-transformers-compat.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: transformers-compat
version: 0.5.1.4
id: transformers-compat-0.5.1.4-IuFogs8HAVUJBWVNMhtssu
key: transformers-compat-0.5.1.4-IuFogs8HAVUJBWVNMhtssu
license: BSD3
copyright: Copyright (C) 2012-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/transformers-compat/
synopsis: A small compatibility shim exposing the new types from transformers 0.3 and 0.4 to older Haskell platforms.
description:
    This package includes backported versions of types that were added
    to transformers in transformers 0.3, 0.4, and 0.5 for users who need strict
    transformers 0.2 or 0.3 compatibility to run on old versions of the
    platform, but also need those types.
    .
    Those users should be able to just depend on @transformers >= 0.2@
    and @transformers-compat >= 0.3@.
    .
    Note: missing methods are not supplied, but this at least permits the types to be used.
category: Compatibility
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Monad.Trans.Instances
hidden-modules: Paths_transformers_compat
abi: ae97b35078b768d33fb6895f244890de
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/transformers-compat-0.5.1.4
library-dirs: /usr/lib/ghc-8.0.2/site-local/transformers-compat-0.5.1.4
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/transformers-compat-0.5.1.4
hs-libraries: HStransformers-compat-0.5.1.4-IuFogs8HAVUJBWVNMhtssu
depends:
    base-4.9.1.0 ghc-prim-0.5.0.0 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-transformers-compat/html/transformers-compat.haddock
haddock-html: /usr/share/doc/haskell-transformers-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
